package com.tcctlo.law.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.tcctlo.common.utils.StringUtils;
import com.tcctlo.law.entity.ImpulseInformation;
import com.baomidou.mybatisplus.extension.service.IService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tcctlo.law.mapper.ImpulseInformationMapper;
import com.tcctlo.law.service.IImpulseInformationService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Collections;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 利冲信息表 服务实现类
 * </p>
 *
 * @author 张世琪
 * @since 2025-02-06
 */
@Service
public class ImpulseInformationServiceImpl extends ServiceImpl<ImpulseInformationMapper, ImpulseInformation> implements IImpulseInformationService {


    @Resource
    private ImpulseInformationMapper impulseInformationMapper;

    @Override
    public Page<ImpulseInformation> list(Integer pageNo, Integer pageSize) {
        return impulseInformationMapper.selectPage(new Page<>(pageNo, pageSize), new QueryWrapper<>());
    }

    @Override
    public List<ImpulseInformation> selectLikeByParam(String caseName, Integer isClient) {
        LambdaQueryWrapper<ImpulseInformation> wrapper = new LambdaQueryWrapper<>();
        wrapper.like(StringUtils.isNotNull(caseName), ImpulseInformation::getCaseName, caseName)
                .eq(StringUtils.isNotNull(isClient), ImpulseInformation::getIsClient, isClient)
                .eq(ImpulseInformation::getDelFlag, 0)
                .eq(ImpulseInformation::getStatus, 0)
                .orderByDesc(ImpulseInformation::getCreateTime);
        return impulseInformationMapper.selectList(wrapper);
    }

    @Override
    public Boolean retrievalConflict(ImpulseInformation impulseInformation) {
        /**
         * 当 impulseInformation.getIsClient() 的值为 0 时，1 - 0 结果为 1；当 impulseInformation.getIsClient() 的值为 1 时，1 - 1 结果为 0
         * 注意：
         * 1、如果是【委托方】就去检索【相对方】中有没有
         * 2、如果是【相对方】就去检索【委托方】中有没有
         * 3、【委托方】不能是律所中任何一个案件的被告方====【被告方】不能是律所中任何一个案件的【委托方】
         */
        impulseInformation.setIsClient(1 - impulseInformation.getIsClient());
        List<ImpulseInformation> resList = impulseInformationMapper.retrievalConflict(impulseInformation);
        return resList.isEmpty();
    }

    @Override
    public ImpulseInformation getById(Long id) {
        ImpulseInformation impulseInformation = impulseInformationMapper.selectById(id);
        return impulseInformation;
    }

    @Override
    public Integer create(ImpulseInformation impulseInformation) {
        return impulseInformationMapper.insert(impulseInformation);
    }

    @Override
    public Integer delete(Long id) {
        return impulseInformationMapper.deleteById(id);
    }

    @Override
    public Integer update(ImpulseInformation impulseInformation) {
        return impulseInformationMapper.updateById(impulseInformation);
    }


}
